==> adscounter-rtb-common-1.19.1-sources.jar: com/bxm/adscounter/rtb/common/autoconfigure/FeedbackServiceAutoConfiguration.java <==
package com.bxm.adscounter.rtb.common.autoconfigure;

import com.bxm.adscounter.rtb.common.impl.mengran.MengranRtbIntegration;
import com.bxm.adscounter.rtb.common.service.*;
import org.springframework.context.annotation.Bean;

/**
 * @author allen
 * @date 2022-05-13
 * @since 1.0
 */
public class FeedbackServiceAutoConfiguration {

    @Bean
    public PositionRtbService positionRtbService() {
        return new DefaultPositionRtbService();
    }

    // ---------------- Feedback service instances ---------------- //

    @Bean
    public KuaishouFeedbackService kuaishouFeedbackService() {
        return new KuaishouFeedbackService();
    }

    @Bean
    public BaiduFeedbackService baiduFeedbackService() {
        return new BaiduFeedbackService();
    }

    @Bean
    public IqiyiFeedbackService iqiyiFeedbackService() {
        return new IqiyiFeedbackService();
    }

    @Bean
    public UCFeedbackService ucFeedbackService() {
        return new UCFeedbackService();
    }

    @Bean
    public TencentFeedbackService tencentFeedbackService() {
        return new TencentFeedbackService();
    }

    @Bean
    public OceanEngineFeedbackService oceanEngineFeedbackService() {
        return new OceanEngineFeedbackService();
    }

    @Bean
    public WyydFeedbackService wyydFeedbackService() {
        return new WyydFeedbackService();
    }

    @Bean
    public HimalayanFeedbackService himalayanFeedbackService() {
        return new HimalayanFeedbackService();
    }

    @Bean
    public JiGuangFeedbackService jiGuangFeedbackService() {
        return new JiGuangFeedbackService();
    }

    @Bean
    public AlipayLifeFeedbackService alipayLifeFeedbackService() {
        return new AlipayLifeFeedbackService();
    }

    @Bean
    public QttFeedbackService qttFeedbackService() {
        return new QttFeedbackService();
    }

    @Bean
    public JiGuangAdxFeedbackService jiGuangAdxFeedbackService() {
        return new JiGuangAdxFeedbackService();
    }

    @Bean
    public XiaomiFeedbackService xiaomiFeedbackService() {
        return new XiaomiFeedbackService();
    }

    @Bean
    public VivoFeedbackService vivoFeedbackService() {
        return new VivoFeedbackService();
    }

    @Bean
    public MeituanFeedbackService meituanFeedbackService() {
        return new MeituanFeedbackService();
    }

    @Bean
    public WIFIFeedbackService wifiFeedbackService() {
        return new WIFIFeedbackService();
    }

    @Bean
    public WeiBoFeedbackService weiBoFeedbackService() {
        return new WeiBoFeedbackService();
    }

    @Bean
    public BigoFeedbackService bigoFeedbackService() {
        return new BigoFeedbackService();
    }

    @Bean
    public OppoFeedbackService oppoFeedbackService() {
        return new OppoFeedbackService();
    }

    @Bean
    public SigmobDspFeedbackService sigmobDspFeedbackService() {
        return new SigmobDspFeedbackService();
    }

    @Bean
    public DomobFeedbackService domobFeedbackService() {
        return new DomobFeedbackService();
    }
    @Bean
    public MintegralFeedbackService mintegralFeedbackService() {
        return new MintegralFeedbackService();
    }

    @Bean
    public AdbeeFeedbackService abdeeFeedbackService() {
        return new AdbeeFeedbackService();
    }

    @Bean
    public BilibiliFeedbackService bilibiliFeedbackService() {
        return new BilibiliFeedbackService();
    }

    @Bean
    public RuishiFeedbackService ruishiFeedbackService() {
        return new RuishiFeedbackService();
    }

    @Bean
    public SouHuFeedbackService souHuFeedbackService() {
        return new SouHuFeedbackService();
    }

    @Bean
    public YiXiaoFeedbackService yiXiaoFeedbackService() {
        return new YiXiaoFeedbackService();
    }

    @Bean
    public QiMaoFeedbackService qiMaoFeedbackService() {
        return new QiMaoFeedbackService();
    }

    @Bean
    public XunFeiFeedbackService xunFeiFeedbackService() {
        return new XunFeiFeedbackService();
    }

    @Bean
    public KuaiKanFeedbackService kuaiKanFeedbackService() {
        return new KuaiKanFeedbackService();
    }

    @Bean
    public SigmobInadsFeedbackService sigmobInadsFeedbackService() {
        return new SigmobInadsFeedbackService();
    }

    @Bean
    public BxmFeedbackService bxmFeedbackService() {
        return new BxmFeedbackService();
    }

    @Bean
    public Pc360FeedbackService pc360FeedbackService() {
        return new Pc360FeedbackService();
    }

    @Bean
    public YoukuFeedbackService youkuFeedbackService() {
        return new YoukuFeedbackService();
    }

    @Bean
    public IfengFeedbackService ifengFeedbackService() {
        return new IfengFeedbackService();
    }

    @Bean
    public WeiBoDownloadFeedbackService weiBoDownloadFeedbackService() {
        return new WeiBoDownloadFeedbackService();
    }
    @Bean
    public HuaweiFeedbackService huaweiFeedbackService() {
        return new HuaweiFeedbackService();
    }

    @Bean
    public AlipayDHFeedbackService alipayDHFeedbackService() {
        return new AlipayDHFeedbackService();
    }
    @Bean
    public MengranFeedbackService mengranFeedbackService() {
        return new MengranFeedbackService();
    }
}

==> adscounter-rtb-common-1.19.6-sources.jar: com/bxm/adscounter/rtb/common/autoconfigure/FeedbackServiceAutoConfiguration.java <==
package com.bxm.adscounter.rtb.common.autoconfigure;

import com.bxm.adscounter.rtb.common.impl.mengran.MengranRtbIntegration;
import com.bxm.adscounter.rtb.common.service.*;
import org.springframework.context.annotation.Bean;

/**
 * @author allen
 * @date 2022-05-13
 * @since 1.0
 */
public class FeedbackServiceAutoConfiguration {

    @Bean
    public PositionRtbService positionRtbService() {
        return new DefaultPositionRtbService();
    }

    // ---------------- Feedback service instances ---------------- //

    @Bean
    public KuaishouFeedbackService kuaishouFeedbackService() {
        return new KuaishouFeedbackService();
    }

    @Bean
    public BaiduFeedbackService baiduFeedbackService() {
        return new BaiduFeedbackService();
    }

    @Bean
    public IqiyiFeedbackService iqiyiFeedbackService() {
        return new IqiyiFeedbackService();
    }

    @Bean
    public UCFeedbackService ucFeedbackService() {
        return new UCFeedbackService();
    }

    @Bean
    public TencentFeedbackService tencentFeedbackService() {
        return new TencentFeedbackService();
    }

    @Bean
    public OceanEngineFeedbackService oceanEngineFeedbackService() {
        return new OceanEngineFeedbackService();
    }

    @Bean
    public WyydFeedbackService wyydFeedbackService() {
        return new WyydFeedbackService();
    }

    @Bean
    public HimalayanFeedbackService himalayanFeedbackService() {
        return new HimalayanFeedbackService();
    }

    @Bean
    public JiGuangFeedbackService jiGuangFeedbackService() {
        return new JiGuangFeedbackService();
    }

    @Bean
    public AlipayLifeFeedbackService alipayLifeFeedbackService() {
        return new AlipayLifeFeedbackService();
    }

    @Bean
    public QttFeedbackService qttFeedbackService() {
        return new QttFeedbackService();
    }

    @Bean
    public JiGuangAdxFeedbackService jiGuangAdxFeedbackService() {
        return new JiGuangAdxFeedbackService();
    }

    @Bean
    public XiaomiFeedbackService xiaomiFeedbackService() {
        return new XiaomiFeedbackService();
    }

    @Bean
    public VivoFeedbackService vivoFeedbackService() {
        return new VivoFeedbackService();
    }

    @Bean
    public MeituanFeedbackService meituanFeedbackService() {
        return new MeituanFeedbackService();
    }

    @Bean
    public WIFIFeedbackService wifiFeedbackService() {
        return new WIFIFeedbackService();
    }

    @Bean
    public WeiBoFeedbackService weiBoFeedbackService() {
        return new WeiBoFeedbackService();
    }

    @Bean
    public BigoFeedbackService bigoFeedbackService() {
        return new BigoFeedbackService();
    }

    @Bean
    public OppoFeedbackService oppoFeedbackService() {
        return new OppoFeedbackService();
    }

    @Bean
    public SigmobDspFeedbackService sigmobDspFeedbackService() {
        return new SigmobDspFeedbackService();
    }

    @Bean
    public DomobFeedbackService domobFeedbackService() {
        return new DomobFeedbackService();
    }
    @Bean
    public MintegralFeedbackService mintegralFeedbackService() {
        return new MintegralFeedbackService();
    }

    @Bean
    public AdbeeFeedbackService abdeeFeedbackService() {
        return new AdbeeFeedbackService();
    }

    @Bean
    public BilibiliFeedbackService bilibiliFeedbackService() {
        return new BilibiliFeedbackService();
    }

    @Bean
    public RuishiFeedbackService ruishiFeedbackService() {
        return new RuishiFeedbackService();
    }

    @Bean
    public SouHuFeedbackService souHuFeedbackService() {
        return new SouHuFeedbackService();
    }

    @Bean
    public YiXiaoFeedbackService yiXiaoFeedbackService() {
        return new YiXiaoFeedbackService();
    }

    @Bean
    public QiMaoFeedbackService qiMaoFeedbackService() {
        return new QiMaoFeedbackService();
    }

    @Bean
    public XunFeiFeedbackService xunFeiFeedbackService() {
        return new XunFeiFeedbackService();
    }

    @Bean
    public KuaiKanFeedbackService kuaiKanFeedbackService() {
        return new KuaiKanFeedbackService();
    }

    @Bean
    public SigmobInadsFeedbackService sigmobInadsFeedbackService() {
        return new SigmobInadsFeedbackService();
    }

    @Bean
    public BxmFeedbackService bxmFeedbackService() {
        return new BxmFeedbackService();
    }

    @Bean
    public Pc360FeedbackService pc360FeedbackService() {
        return new Pc360FeedbackService();
    }

    @Bean
    public YoukuFeedbackService youkuFeedbackService() {
        return new YoukuFeedbackService();
    }

    @Bean
    public IfengFeedbackService ifengFeedbackService() {
        return new IfengFeedbackService();
    }

    @Bean
    public WeiBoDownloadFeedbackService weiBoDownloadFeedbackService() {
        return new WeiBoDownloadFeedbackService();
    }
    @Bean
    public HuaweiFeedbackService huaweiFeedbackService() {
        return new HuaweiFeedbackService();
    }

    @Bean
    public AlipayDHFeedbackService alipayDHFeedbackService() {
        return new AlipayDHFeedbackService();
    }
    @Bean
    public MengranFeedbackService mengranFeedbackService() {
        return new MengranFeedbackService();
    }
    @Bean
    public BaicaiFeedbackService baicaiFeedbackService() {
        return new BaicaiFeedbackService();
    }
    @Bean
    public LiuLiangGuoFeedbackService liuLiangGuoFeedbackService() {
        return new LiuLiangGuoFeedbackService();
    }
    @Bean
    public SinaFeedbackService sinaFeedbackService() {
        return new SinaFeedbackService();
    }
    @Bean
    public MangGuoFeedbackService mangGuoFeedbackService() {
        return new MangGuoFeedbackService();
    }
}
